<?php
error_reporting(E_ALL);

/**
 * 萔ƃRg[NX̓ǂݍ
 *
 * Tv𓮍삳ꍇ́Ãt@ChLg[gȉɃRs[A
 *   ́uSyL.phpv܂ł̃pXK؂ɏCĂB
 */
require_once '../SyL.php';

/**
 * Np[^̐ݒ
 *
 *  project_dir - vWFNgfBNg
 *  app_name    - AvP[V
 *  action_key  - ANVp[^̃L[
 *  cache       - LbVgp@i͂ŃLbVgpȂj
 */
$config = array(
  'project_dir'  => SYL_DIR . '/example/webapp',
  'app_name'     => 'example',
  'action_key'   => 'action',
  'cache'        => false
);

/**
 * t[[NN
 */
SyL_Controller::streaming($config);

?>
